# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.tarfileUnsafeMembers

Module implementing checks for insecure use of 'tarfile.extracall()'.

### Global Attributes

None

### Classes

None

### Functions

_getMembersValue | Function to extract the value of the 'members' argument.
_isFilterData | Function to check for the filter argument to be 'data'.
checkTarfileUnsafeMembers | Function to check for insecure use of 'tarfile.extracall()'.
getChecks | Public method to get a dictionary with checks handled by this module.

## _getMembersValue

_getMembersValue(context)

Function to extract the value of the 'members' argument.

context (SecurityContext)
  security context object

Return:
  dictionary containing the argument value

Return Type:
  dict

Up

## _isFilterData

_isFilterData(context)

Function to check for the filter argument to be 'data'.

context (SecurityContext)
  security context object

Return:
  flag indicating the 'data' filter

Return Type:
  bool

Up

## checkTarfileUnsafeMembers

checkTarfileUnsafeMembers(reportError, context, _config)

Function to check for insecure use of 'tarfile.extracall()'.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up